aboutsummaryrefslogtreecommitdiffstats
path: root/wsutil
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2015-04-16 11:38:04 -0700
committerGerald Combs <gerald@wireshark.org>2015-04-17 18:08:36 +0000
commit3d7b72817301530000efd2ae44d7b34bbe57318d (patch)
tree17c8216abc9c77f46d36b3b3ef110a670223ca94 /wsutil
parentf2070bdbf973f0c5de6b2dd0532aea46e8e05f63 (diff)
Make androiddump loadable on OS X.
Make sure the target location for extcap executables and extcap_dir match on OS X. Set the extcap directory to Contents/MacOS/extcap. The Mac Developer Library documentation doesn't explicitly define "Resources", but examples include data files and not executables. It does state that executables shouldn't go into PlugIns. Make sure we rpathify androiddump. Change-Id: If36c762e2a1991c26e5c01a870deaf191bcf9f94 Reviewed-on: https://code.wireshark.org/review/8093 Reviewed-by: Gerald Combs <gerald@wireshark.org>
Diffstat (limited to 'wsutil')
-rw-r--r--wsutil/filesystem.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/wsutil/filesystem.c b/wsutil/filesystem.c
index 0b23aec1ee..3cfc1b87ee 100644
--- a/wsutil/filesystem.c
+++ b/wsutil/filesystem.c
@@ -1119,7 +1119,7 @@ static void init_extcap_dir(void) {
#ifdef __APPLE__
/*
* If we're running from an app bundle and weren't started
* with special privileges, use the Contents/Resources/lib/wireshark/extcap
* subdirectory of the app bundle.
*
* (appbundle_dir is not set to a non-null value if we're
@@ -1127,7 +1127,7 @@ static void init_extcap_dir(void) {
* it; we don't need to call started_with_special_privs().)
*/
else if (appbundle_dir != NULL) {
- extcap_dir = g_strdup_printf("%s/Contents/Resources/lib/wireshark/extcap",
+ extcap_dir = g_strdup_printf("%s/Contents/MacOS/extcap",
appbundle_dir);
}
#endif
@@ -1119,7 +1119,7 @@ static void init_extcap_dir(void) {
/*
* If we're running from an app bundle and weren't started
- * with special privileges, use the Contents/Resources/lib/wireshark/extcap
+ * with special privileges, use the Contents/MacOS/extcap
* subdirectory of the app bundle.
*